geowatch.tasks.dino\_detector.building\_validator module
========================================================

.. automodule:: geowatch.tasks.dino_detector.building_validator
   :members:
   :undoc-members:
   :show-inheritance:
